@@ -322,7 +322,7 @@ Node::~Node()
 	delete[] m_pIdentifier;
 }
 
-Node& Node::operator=(const Node& n)
+Node& Node::operator=(const Node&)
 {
 	throw Tools::IllegalStateException("Node::operator =: This should never be called.");
 }
